@@ -1,4 +1,3 @@
-{-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE GADTs #-}
 {-# LANGUAGE LambdaCase #-}
 {-# LANGUAGE OverloadedStrings #-}
@@ -32,6 +31,7 @@ module Ormolu.Printer.Combinators
     located,
     located',
     switchLayout,
+    switchLayoutNoLimit,
     Layout (..),
     vlayout,
     getLayout,
@@ -95,7 +95,7 @@ where
 import Control.Monad
 import Data.List (intersperse)
 import Data.Text (Text)
-import qualified GHC.Data.Strict as Strict
+import GHC.Data.Strict qualified as Strict
 import GHC.LanguageExtensions.Type
 import GHC.Types.SrcLoc
 import Ormolu.Config
@@ -151,22 +151,48 @@ located' = flip located
 -- provided by GHC AST. It is relatively rare that this one is needed.
 --
 -- Given empty list this function will set layout to single line.
-switchLayout ::
+switchLayout' ::
+  -- | Should enforce column limit, if one is set
+  Bool ->
   -- | Span that controls layout
   [SrcSpan] ->
   -- | Computation to run with changed layout
   R () ->
   R ()
-switchLayout spans' = enterLayout (spansLayout spans')
+switchLayout' useColLimit spans' r = do
+  columnLimit <-
+    if useColLimit then getPrinterOpt poColumnLimit else pure NoLimit
+  enterLayout (spansLayout columnLimit spans') r
+
+switchLayout :: [SrcSpan] -> R () -> R ()
+switchLayout = switchLayout' True
+
+-- | Switch layout version that disregards the column limit.
+-- It should be used for the argument list in function definitions because
+-- the column limit can't be enforced there without changing the AST.
+switchLayoutNoLimit :: [SrcSpan] -> R () -> R ()
+switchLayoutNoLimit = switchLayout' False
 
 -- | Which layout combined spans result in?
-spansLayout :: [SrcSpan] -> Layout
-spansLayout = \case
+spansLayout :: ColumnLimit -> [SrcSpan] -> Layout
+spansLayout colLimit = \case
   [] -> SingleLine
   (x : xs) ->
-    if isOneLineSpan (foldr combineSrcSpans x xs)
+    if isOneLineSpan combinedSpan && not (shouldBreakSingleLine combinedSpan)
       then SingleLine
       else MultiLine
+    where
+      combinedSpan = foldr combineSrcSpans x xs
+
+      shouldBreakSingleLine :: SrcSpan -> Bool
+      shouldBreakSingleLine (RealSrcSpan rs _) =
+        case colLimit of
+          ColumnLimit maxLineLength ->
+            spanLineLength > fromIntegral maxLineLength
+          NoLimit -> False
+        where
+          spanLineLength = srcSpanEndCol rs - srcSpanStartCol rs
+      shouldBreakSingleLine _ = False
 
 -- | Insert a space if enclosing layout is single-line, or newline if it's
 -- multiline.
